Noncommutative Polynomials
==========================

Univariate Ore Polynomials
--------------------------

.. toctree::
   :maxdepth: 1

   sage/rings/polynomial/ore_polynomial_ring
   sage/rings/polynomial/ore_polynomial_element
   sage/rings/polynomial/skew_polynomial_ring
   sage/rings/polynomial/skew_polynomial_element
   sage/rings/polynomial/skew_polynomial_finite_order
   sage/rings/polynomial/skew_polynomial_finite_field
   sage/rings/polynomial/ore_function_field
   sage/rings/polynomial/ore_function_element

Noncommutative Multivariate Polynomials
---------------------------------------

.. toctree::
   :maxdepth: 1

   sage/rings/polynomial/plural

.. include:: ../footer.txt

